<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Main Kitar Core Class
 *
 * The main class that initiates and runs the plugin.
 *
 * @since 1.0.0
 */

final class Kitar_Extension {

	/**
	 * Plugin Version
	 *
	 * @since 1.0.0
	 *
	 * @var string The plugin version.
	 */
	const VERSION = '1.0.0';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum Elementor version required to run the plugin.
	 */

	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '7.0';


	/**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var Elementor_Test_Extension The single instance of the class.
	 */

	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 * @static
	 *
	 * @return Elementor_Test_Extension An instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'init' ] );
	}

	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init() {

		// Check if Elementor installed and activated

		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}

		// Check for required Elementor version

		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}

		// Check for required PHP version

		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
		}


		// Add Plugin actions

		add_action( 'elementor/widgets/register', [ $this, 'init_widgets' ] );


        // Register widget scripts

		add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'widget_scripts' ]);


		// Specific Register widget scripts

		// add_action( 'elementor/frontend/after_register_scripts', [ $this, 'kitar_regsiter_widget_scripts' ] );
		// add_action( 'elementor/frontend/before_register_scripts', [ $this, 'kitar_regsiter_widget_scripts' ] );


        // category register

		add_action( 'elementor/elements/categories_registered',[ $this, 'kitar_elementor_widget_categories' ] );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'kitar' ),
			'<strong>' . esc_html__( 'Kitar Core', 'kitar' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'kitar' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */

			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'kitar' ),
			'<strong>' . esc_html__( 'Kitar Core', 'kitar' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'kitar' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}
	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_php_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(

			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'kitar' ),
			'<strong>' . esc_html__( 'Kitar Core', 'kitar' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'kitar' ) . '</strong>',
			 self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	/**
	 * Init Widgets
	 *
	 * Include widgets files and register them
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */

	public function init_widgets() {

		$widget_register = \Elementor\Plugin::instance()->widgets_manager;

		// Header Include file & Widget Register
		require_once( KITAR_ADDONS . '/header/header.php' );
		require_once( KITAR_ADDONS . '/header/header2.php' );

		$widget_register->register ( new \Kitar_Header() );
		$widget_register->register ( new \Kitar_Header2() );


		// Include All Widget Files
		foreach($this->Kitar_Include_File() as $widget_file_name){
			require_once( KITAR_ADDONS . '/widgets/kitar-'."$widget_file_name".'.php' );
		}
		// All Widget Register
		foreach($this->Kitar_Register_File() as $name){
			$widget_register->register ( $name );
		}
		
	}

	public function Kitar_Include_File(){
		return [
			'banner', 
			'banner2',
			'section-title', 
			'button', 
			'blog', 
			'service', 
			'testimonial', 
			'team', 
			'team-info', 
			'image', 
			'contact-info', 
			'contact-form', 
			'counterup', 
			'faq', 
			'brand-logo', 
			'cta', 
			'gallery', 
			'info-box', 
			'service-list', 
			'newsletter', 
			'menu-select',
			'footer-widgets',

			'classes',
			'event',
			'event-widgets',

			'social',
			'animated-shape', 
			'animated-shape2', 
			'arrows', 
			'tab-builder', 
			'skill', 
			'step', 
			'features', 
			'video', 
			'price',
			'program',
			'marquee',
			'choose-us',
		];
	}

	public function Kitar_Register_File(){
		return [
			new \Kitar_Banner1(),
			new \Kitar_Banner2(),
			new \Kitar_Section_Title(),
			new \Kitar_Button(),
			new \Kitar_Blog(),
			new \Kitar_Service(),
			new \Kitar_Testimonial(),
			new \Kitar_Team(),
			new \Kitar_Team_info(),
			new \Kitar_Image(),
			new \Kitar_Contact_Info(),
			new \Kitar_Contact_Form(),
			new \Kitar_Counterup(),
			new \Kitar_Faq(),
			new \Kitar_Brand_Logo(),
			new \Kitar_Cta(),
			new \Kitar_Gallery(),
			new \Kitar_Info_Box(),
			new \kitar_Service_List(),
			new \kitar_Newsletter(),
			new \Kitar_Menu(),
			new \Kitar_Footer_Widgets(),

			new \kitar_Classes(),
			new \Kitar_Event(),
			new \Kitar_Event_Widgets(),

			new \Kitar_Social(),
			new \Kitar_Animated_Shape(),
			new \Kitar_Animated_Shape2(),
			new \Kitar_Arrows(),
			new \Kitar_Tab_Builder(),
			new \kitar_Skill(),
			new \kitar_Step(),
			new \Kitar_Features(),
			new \kitar_Video(),
			new \Kitar_Price(),
			new \Kitar_Program(), 
			new \Kitar_Marquee(),
			new \kitar_Choose_Us(),
		];
	}

    public function widget_scripts() {

        // wp_enqueue_script(
        //     'kitar-frontend-script',
        //     KITAR_PLUGDIRURI . 'assets/js/kitar-frontend.js',
        //     array('jquery'),
        //     false,
        //     true
		// );

	}


    function kitar_elementor_widget_categories( $elements_manager ) {

        $elements_manager->add_category(
            'kitar',
            [
                'title' => __( 'Kitar', 'kitar' ),
                'icon' 	=> 'fa fa-plug',
            ]
        );

        $elements_manager->add_category(
            'kitar_footer_elements',
            [
                'title' => __( 'Kitar Footer Elements', 'kitar' ),
                'icon' 	=> 'fa fa-plug',
            ]
		);

		$elements_manager->add_category(
            'kitar_header_elements',
            [
                'title' => __( 'Kitar Header Elements', 'kitar' ),
                'icon' 	=> 'fa fa-plug',
            ]
        );
	}
}

Kitar_Extension::instance();